==> chaosmesh-model-5.3.0-sources.jar: annotations/io/fabric8/chaosmesh/v1alpha1/ServletDelaySpecFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.Integer;
import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;

public interface ServletDelaySpecFluent<A extends ServletDelaySpecFluent<A>> extends Fluent<A> {


    public String getMethod();
    public A withMethod(String method);
    public Boolean hasMethod();
    public A withNewMethod(StringBuilder arg1);
    public A withNewMethod(int[] arg1,int arg2,int arg3);
    public A withNewMethod(char[] arg1);
    public A withNewMethod(StringBuffer arg1);
    public A withNewMethod(byte[] arg1,int arg2);
    public A withNewMethod(byte[] arg1);
    public A withNewMethod(char[] arg1,int arg2,int arg3);
    public A withNewMethod(byte[] arg1,int arg2,int arg3);
    public A withNewMethod(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewMethod(String arg1);
    public Integer getOffset();
    public A withOffset(Integer offset);
    public Boolean hasOffset();
    public A withNewOffset(int arg1);
    public String getQuerystring();
    public A withQuerystring(String querystring);
    public Boolean hasQuerystring();
    public A withNewQuerystring(StringBuilder arg1);
    public A withNewQuerystring(int[] arg1,int arg2,int arg3);
    public A withNewQuerystring(char[] arg1);
    public A withNewQuerystring(StringBuffer arg1);
    public A withNewQuerystring(byte[] arg1,int arg2);
    public A withNewQuerystring(byte[] arg1);
    public A withNewQuerystring(char[] arg1,int arg2,int arg3);
    public A withNewQuerystring(byte[] arg1,int arg2,int arg3);
    public A withNewQuerystring(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewQuerystring(String arg1);
    public String getRequestpath();
    public A withRequestpath(String requestpath);
    public Boolean hasRequestpath();
    public A withNewRequestpath(StringBuilder arg1);
    public A withNewRequestpath(int[] arg1,int arg2,int arg3);
    public A withNewRequestpath(char[] arg1);
    public A withNewRequestpath(StringBuffer arg1);
    public A withNewRequestpath(byte[] arg1,int arg2);
    public A withNewRequestpath(byte[] arg1);
    public A withNewRequestpath(char[] arg1,int arg2,int arg3);
    public A withNewRequestpath(byte[] arg1,int arg2,int arg3);
    public A withNewRequestpath(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewRequestpath(String arg1);
    public Integer getTime();
    public A withTime(Integer time);
    public Boolean hasTime();
    public A withNewTime(int arg1);
}

==> chaosmesh-model-5.3.2-sources.jar: annotations/io/fabric8/chaosmesh/v1alpha1/ServletDelaySpecFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.Integer;
import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;

public interface ServletDelaySpecFluent<A extends ServletDelaySpecFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A> {


    public String getMethod();
    public A withMethod(String method);
    public Boolean hasMethod();
    public A withNewMethod(StringBuilder arg1);
    public A withNewMethod(int[] arg1,int arg2,int arg3);
    public A withNewMethod(char[] arg1);
    public A withNewMethod(StringBuffer arg1);
    public A withNewMethod(byte[] arg1,int arg2);
    public A withNewMethod(byte[] arg1);
    public A withNewMethod(char[] arg1,int arg2,int arg3);
    public A withNewMethod(byte[] arg1,int arg2,int arg3);
    public A withNewMethod(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewMethod(String arg1);
    public Integer getOffset();
    public A withOffset(Integer offset);
    public Boolean hasOffset();
    public A withNewOffset(int arg0);
    public String getQuerystring();
    public A withQuerystring(String querystring);
    public Boolean hasQuerystring();
    public A withNewQuerystring(StringBuilder arg1);
    public A withNewQuerystring(int[] arg1,int arg2,int arg3);
    public A withNewQuerystring(char[] arg1);
    public A withNewQuerystring(StringBuffer arg1);
    public A withNewQuerystring(byte[] arg1,int arg2);
    public A withNewQuerystring(byte[] arg1);
    public A withNewQuerystring(char[] arg1,int arg2,int arg3);
    public A withNewQuerystring(byte[] arg1,int arg2,int arg3);
    public A withNewQuerystring(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewQuerystring(String arg1);
    public String getRequestpath();
    public A withRequestpath(String requestpath);
    public Boolean hasRequestpath();
    public A withNewRequestpath(StringBuilder arg1);
    public A withNewRequestpath(int[] arg1,int arg2,int arg3);
    public A withNewRequestpath(char[] arg1);
    public A withNewRequestpath(StringBuffer arg1);
    public A withNewRequestpath(byte[] arg1,int arg2);
    public A withNewRequestpath(byte[] arg1);
    public A withNewRequestpath(char[] arg1,int arg2,int arg3);
    public A withNewRequestpath(byte[] arg1,int arg2,int arg3);
    public A withNewRequestpath(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewRequestpath(String arg1);
    public Integer getTime();
    public A withTime(Integer time);
    public Boolean hasTime();
    public A withNewTime(int arg0);
}
